@@ -1,4 +1,3 @@
-
 #' Print skimmed data frame
 #' 
 #' Prints a skimmed data frame (created by skim()).
@@ -9,6 +8,9 @@
 #' @export
 
 print.skim_df <- function(x, ...) {
+  defaults <- options(dplyr.show_progress = FALSE)
+  on.exit(options(defaults))
+  
   cat("Skim summary statistics\n")
   cat(" n obs:", attr(x, "data_rows"), "\n")
   cat(" n variables:", attr(x, "data_cols"), "\n")
@@ -43,47 +45,42 @@ print.skim_vector <- function(x, ...) {
 
 print_impl <- function(transformed_df, skim_type, ...) {
   cat("\nVariable type:", skim_type, "\n")
-  print(structure(transformed_df, class = "data.frame"), ...)
+  mat <- as.matrix(transformed_df)
+  dimnames(mat)[[1]] <- rep("", nrow(mat))
+  print(enc2utf8(mat), quote = FALSE, right = TRUE)
+  transformed_df
 }
 
 #' Create kable object
 #' 
-#' Generic method for \code{kable} objects based on the method in the knitr package.
+#' Generic method for \code{kable} objects based on the method in the knitr
+#' package.
 #' @seealso \code{\link[knitr]{kable}}
-#' @param x	an R object (typically a matrix or data frame)
-#'    format	a character string; possible values are latex, html, markdown, pandoc, 
-#'    and rst; this will be automatically determined if the function is called
-#'    within knitr; it can also be set in the global option knitr.table.format; 
-#'    if format is a function, it must return a character string.
-#'    format	a character string; possible values are latex, html, markdown, 
-#'    pandoc, and rst; this will be automatically determined if the function 
-#'    is called within knitr; it can also be set in the global option 
-#'    knitr.table.format; if format is a function, it must return a character 
-#'    string
-#' @param  format a character string; possible values are latex, html, markdown, 
-#'    pandoc, and rst; this will be automatically determined if the function
-#'    is called within knitr; it can also be set in the global option 
-#'    knitr.table.format; if format is a function, it must return a character 
-#'    string.  Defaults to NULL.
-#' @param digits  The maximum number of digits for numeric columns (passed to round()); 
-#'    it can also be a vector of length ncol(x) to set the number of digits for
-#'    individual columns
-#' @param row.names a logical value indicating whether to include row names; by default, 
-#'    row names are included if rownames(x) is neither NULL nor identical to 1:nrow(x)
+#' @param x An R object (typically a matrix or data frame)
+#' @param format a character string; possible values are latex, html, markdown,
+#'  pandoc, and rst; this will be automatically determined if the function
+#'  is called within knitr; it can also be set in the global option 
+#'  knitr.table.format; if format is a function, it must return a character 
+#'  string.  Defaults to NULL.
+#' @param digits  The maximum number of digits for numeric columns (passed to
+#'  round()); it can also be a vector of length ncol(x) to set the number of
+#'  digits for individual columns
+#' @param row.names a logical value indicating whether to include row names;
+#'  by default, row names are included if rownames(x) is neither NULL nor
+#'  identical to 1:nrow(x)
 #' @param col.names a character vector of column names to be used in the table
 #' @param align  the alignment of columns: a character vector consisting of 
-#'    'l' (left), 'c' (center) and/or 'r' (right); by default, numeric columns are 
-#'    right-aligned, and other columns are left-aligned; if align = NULL, the 
-#'    default alignment is used; alternatively, if length(align) == 1L, the 
-#'    string will be expanded to a vector of individual letters unless the 
-#'    output format is LaTeX; for example, 'clc' will be converted to 
-#'    c('c', 'l', 'c')
+#'  'l' (left), 'c' (center) and/or 'r' (right); by default, numeric columns
+#'  are right-aligned, and other columns are left-aligned; if align = NULL,
+#'  the default alignment is used; alternatively, if length(align) == 1L, the
+#'  string will be expanded to a vector of individual letters unless the 
+#'  output format is LaTeX; for example, 'clc' will be converted to 
+#'  c('c', 'l', 'c')
 #' @param caption  the table caption
-#' @param format.args a list of arguments to be passed to format() to format table 
-#'    values, e.g. list(big.mark = ',')
+#' @param format.args a list of arguments to be passed to format() to format
+#'  table values, e.g. list(big.mark = ',')
 #' @param escape escape special characters when producing HTML or LaTeX tables
 #' @param ... other arguments 
-#' 
 #' @export
 
 kable <- function (x, format = NULL, digits = getOption("digits"), 
@@ -130,6 +127,9 @@ kable.skim_df <- function(x, format = NULL, digits = getOption("digits"),
                           row.names = NA, col.names = NA, align = NULL, 
                           caption = NULL, format.args = list(), 
                           escape = TRUE, ...) {
+  defaults <- options(dplyr.show_progress = FALSE)
+  on.exit(options(defaults))
+  
   # Spaces are markdown new lines
   cat("Skim summary statistics  \n")
   cat(" n obs:", attr(x, "data_rows"), "   \n")
@@ -147,11 +147,20 @@ kable_impl <- function(transformed_df, skim_type, format , digits, row.names,
                        escape, ...) {
   cat(sprintf("\nVariable type: %s", skim_type))
   if(is.null(align)) align <- rep("l", length(transformed_df))
-  print(kable(transformed_df, caption = NULL, align = align, format, digits,
-        row.names,  col.names, format.args,  escape, ...))
+  kabled <- kable(transformed_df, caption = NULL, align = align, format, digits,
+        row.names,  col.names, format.args,  escape, ...)
+  if (is_windows()) {
+    kabled[] <- fix_unicode(kabled)
+  }
+  print(kabled)
   transformed_df
 }
+
  
+#' @importFrom pander pander
+#' @export
+pander::pander
+
 #' Produce \code{pander} output of a skimmed data frame
 #'
 #' @seealso \code{\link[pander]{pander}}
@@ -161,7 +170,15 @@ kable_impl <- function(transformed_df, skim_type, format , digits, row.names,
 #' @return The original \code{skim_df} object.
 #' @export
 
-pander.skim_df <- function(x,caption = attr(x, "caption"), ...) {
+pander.skim_df <- function(x, caption = attr(x, "caption"), ...) {
+  defaults <- options(dplyr.show_progress = FALSE)
+  on.exit(options(defaults))
+  
+  if (is_windows()) {
+    warning("Skimr's histograms incorrectly render with pander on Windows.",
+            " Removing them. Use kable() if you'd like them rendered.",
+            call. = FALSE)
+  }
   cat("Skim summary statistics  \n  ")
   # Spaces are markdown new lines.
   cat(" n obs:", attr(x, "data_rows"), "   \n")
@@ -178,7 +195,10 @@ pander_impl <- function(transformed_df, skim_type, caption) {
     # Intentionally commented due to issue in pandoc
     # caption = cat(sprintf("\nVariable type: %s", skim_type))
   }
-  transformed_df <- dplyr::ungroup(transformed_df) 
+  if (is_windows()) {
+    transformed_df$hist <- NULL 
+  }
+  transformed_df <- dplyr::ungroup(transformed_df)
   pander(structure(transformed_df, class = "data.frame"))
   transformed_df
 }
@@ -234,7 +254,5 @@ print.spark <- function(x, ...) {
 #' @noRd
 
 quiet_impl <- function(transformed_df, skim_type, ...) {
-
   structure(transformed_df, class = c( "tbl", "tbl_df", "data.frame"))
 }
-
